Installation
============


For the following to work you have to have Python's `setuptools` 
(from `<http://pypi.python.org/pypi/setuptools>`_ ) to be installed.

selexe requires selenium to be installed (`easy_install selenium`). However this
should be installed automatically when selexe is installed in the next step.

Then from your unix/windows command line run::

  easy_install selexe

In the next section you'll find instructions how to use selexe.
  
